@@ -39,7 +39,10 @@ import aws_cdk.aws_stepfunctions._jsii
 import aws_cdk.core._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-solutions-constructs/core", "1.86.0", __name__[0:-6], "core@1.86.0.jsii.tgz"
+    "@aws-solutions-constructs/core",
+    "1.100.0",
+    __name__[0:-6],
+    "core@1.100.0.jsii.tgz",
 )
 
 __all__ = [
